@@ -9,9 +9,16 @@ use Lemonldap::NG::Portal::Simple;
 use base qw(Lemonldap::NG::Portal::_WebForm Lemonldap::NG::Portal::_DBI);
 use strict;
 
-our $VERSION = '0.992';
+our $VERSION = '1.0.2';
 our $initDone;
 
+BEGIN {
+    eval {
+        require threads::shared;
+        threads::shared::share($initDone);
+    };
+}
+
 ## @apmethod int authInit()
 # Check DBI paramaters
 #@return Lemonldap::NG::Portal constant
@@ -31,6 +38,8 @@ sub authInit {
         return PE_ERROR;
     }
 
+    $self->{_authnLevel} = $self->{dbiAuthnLevel};
+
     $initDone = 1;
     PE_OK;
 }
@@ -40,7 +49,6 @@ sub authInit {
 #@return Lemonldap::NG::Portal constant
 sub authenticate {
     my $self = shift;
-    $self->{_authnLevel} = $self->{dbiAuthnLevel};
 
     # Connect
     my $dbh =
